Learn R Programming

R.filesets (version 2.15.0)

GenericDataFile$fromFile: Defines a GenericDataFile from a pathname

Description

Defines a GenericDataFile from a pathname.

Usage

## Static method (use this):
## GenericDataFile$fromFile(filename, path=NULL, ..., recursive=TRUE, verbose=FALSE,
##   .checkArgs=TRUE)

## Don't use the below: # S3 method for GenericDataFile fromFile(static, filename, path=NULL, ..., recursive=TRUE, verbose=FALSE, .checkArgs=TRUE)

Value

Returns a GenericDataFile (or a subclass thereof).

Arguments

filename, path

The filename and the path to the file. The file must exist, otherwise an exception is thrown.

unknown

The logical value returned if the timestamp for the previous modification, if any, is unknown.

...

Not used.

recursive

If TRUE, ...

verbose

...

.checkArgs

(Internal) If FALSE, validation of file existence and arguments are skipped.

Author

Henrik Bengtsson

See Also

file.info(). For more information see GenericDataFile.