Learn R Programming

R.filesets (version 2.15.0)

dim.GenericTabularFile: Gets the dimension of data table

Description

Gets the dimension of data table, which is the number of rows and the number of columns.

Usage

# S3 method for GenericTabularFile
dim(x)

Value

Returns an integer

vector of length two.

Arguments

...

Not used.

Author

Henrik Bengtsson

See Also

*nbrOfRows(). For more information see GenericTabularFile.