| nbrOfLines.TabularTextFile {R.filesets} | R Documentation |
Counts the number of lines in the data file
Description
Counts the number of lines in the data file. The count include header rows, comments and more.
Usage
## S3 method for class 'TabularTextFile'
nbrOfLines(this, fast=FALSE, ...)
Arguments
fast |
If |
... |
Optional arguments passed to |
Value
Author(s)
Henrik Bengtsson
See Also
To count the number of data rows is the data table,
use *nbrOfRows().
Internally, countLines is used.
For more information see TabularTextFile.
[Package R.filesets version 2.15.1 Index]