Defines a GenericDataFile from a pathname.
## Static method (use this):
## GenericDataFile$fromFile(filename, path=NULL, ..., recursive=TRUE, verbose=FALSE,
## .checkArgs=TRUE)## Don't use the below:
# S3 method for GenericDataFile
fromFile(static, filename, path=NULL, ..., recursive=TRUE, verbose=FALSE,
.checkArgs=TRUE)
Returns a GenericDataFile (or a subclass thereof).
The filename and the path to the file. The file must exist, otherwise an exception is thrown.
The logical value returned if the timestamp for the
previous modification, if any, is unknown.
Not used.
If TRUE, ...
...
(Internal) If FALSE, validation of file existence and arguments are skipped.
Henrik Bengtsson
file.info().
For more information see GenericDataFile.